==> mysql-8.4_8.4.8.orig.tar.gz: mysql-8.4.8/components/keyrings/common/json_data/json_ds.h <==
/* Copyright (c) 2021, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef JSON_DS_INCLUDED
#define JSON_DS_INCLUDED

#include <string>

namespace keyring_common {

namespace json_data {

/* Base class for data extensions */
class Json_data_extension {
 public:
  Json_data_extension() = default;
  virtual std::string version() { return std::string{"1.0"}; }
  virtual ~Json_data_extension() = default;
};

}  // namespace json_data

}  // namespace keyring_common
#endif  // !JSON_DS_INCLUDED

==> mysql-9.5.0.tar.gz: mysql-9.5.0/components/keyrings/common/json_data/json_ds.h <==
/* Copyright (c) 2021, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef JSON_DS_INCLUDED
#define JSON_DS_INCLUDED

#include <string>

namespace keyring_common::json_data {

/* Base class for data extensions */
class Json_data_extension {
 public:
  Json_data_extension() = default;
  virtual std::string version() { return std::string{"1.0"}; }
  virtual ~Json_data_extension() = default;
};

}  // namespace keyring_common::json_data
#endif  // !JSON_DS_INCLUDED
